WarningMessage

Enum WarningMessage 

pub enum WarningMessage {
Show 17 variants DefinitionTermContinuation, EndTagInComment, InvalidCharacter, InvalidHeadingSyntaxRewinding, InvalidLinkSyntax, InvalidParameterSyntax, InvalidTagSyntax, MissingEndTagRewinding, RepeatedEmptyLine, StrayTextInTable, TextAfterRedirect, UnexpectedEndTagRewinding, UnexpectedEndTag, UnexpectedHeadingLevelCorrecting, UnrecognizedTagName, UselessTextInParameter, UselessTextInRedirect,
}
Identifier for a kind of warning from the parser.

Variants



DefinitionTermContinuation

List broken by definition term.



EndTagInComment

End tag in comment.



InvalidCharacter

Invalid character.



InvalidHeadingSyntaxRewinding

Invalid heading syntax. Rewinding.



InvalidLinkSyntax

Invalid link syntax.



InvalidParameterSyntax

Invalid parameter syntax.



InvalidTagSyntax

Invalid tag syntax.



MissingEndTagRewinding

Missing end tag. Rewinding.



RepeatedEmptyLine

Repeated empty line.



StrayTextInTable

Stray text in table.



TextAfterRedirect

Wiki text comes after a redirect.



UnexpectedEndTagRewinding

The end tag does not match the last start tag. Rewinding.



UnexpectedEndTag

An end tag was found with no preceeding start tag.



UnexpectedHeadingLevelCorrecting

Expected heading of higher level. Correcting start of heading.



UnrecognizedTagName

A tag with an unrecognized tag name was found.



UselessTextInParameter

Useless text in parameter.



UselessTextInRedirect

Useless text in redirect.

Implementations

Source

impl WarningMessage

pub fn message(self) -> &'static str

Human-readable description of the warning.